@@ -22,5 +22,5 @@ typedef unsigned short volatile u16v;
 
 struct test {
     char *name;
-    int (*fp)();
+    int (*fp)(ulv *, ulv*, size_t);
 };
